
package ReadSetAntennaSequence_Powers_ReadGapTimes;

import RFIDReader.PowerSettings;
import RFIDReader.RFIDReader;
import RFIDReader.ReadGapTimes;

/*
 * The following code is an example of how to read/set the antenna sequence,
 * read/set the antenna power, and read/set the read/gap times. To run the
 * code successfully the IP Address must be changed to match that of the reader
 * for intended use.
 */

public class Antenna {
	
	// Usage: java RFIDTester aaa.bbb.ccc.ddd
	// where aaa.bbb.ccc.ddd is the IP Address of the reader that
	// will be used for the test.
		
	static final String DEFAULT_READER_IP_ADDRESS = "192.168.1.120";
	static final int PORT_NUMBER = 5000;	 	
	static RFIDReader reader = null;
	
	public static void main(String[] args){
		try
		{
			String readerIPAddress = DEFAULT_READER_IP_ADDRESS;
			int PortNumber = PORT_NUMBER;

			System.out.println("Setting up ReaderComm instance on IP Address " + readerIPAddress);
			
			reader = new RFIDReader(readerIPAddress, PortNumber);
			
			ReadSequence();
			AntennaPowerSetting();
			ReadGapTimes();

		}
		catch (Exception ex)
		{
			System.out.println("Main: " + ex.toString());
		}
	}
	
	public static void ReadSequence() throws Exception 
	{
		int[] antSeq = Antenna.reader.GetReadSequence();
		
		System.out.print(String.format("Antenna sequence (%d): ", antSeq.length));
		
		for (int idx = 0; idx < antSeq.length; idx++)
			System.out.print(String.format(" %d", antSeq[idx]));
		
		System.out.println();
		
		int[] newAntSeq = new int[5];
		newAntSeq[0] = 1; newAntSeq[1] = 0; newAntSeq[2] = 3; newAntSeq[3] = 2; newAntSeq[4] = 1;
		
		if (Antenna.reader.SetReadSequence(newAntSeq))
			System.out.println("Set antenna sequence succeeded");
		else
			System.out.println("Set antenna sequence failed");				
			
		int[] validateAntSeq = Antenna.reader.GetReadSequence();
		if (validateAntSeq.length != newAntSeq.length)
			System.out.println("Validate antenna sequence failed: length didn't match");
		
		for (int idx = 0; idx < newAntSeq.length; idx++)
		{
			if (validateAntSeq[idx] != newAntSeq[idx])
			{
				System.out.println(String.format("Validate antenna sequence failed: seq[$d] %d != %d", idx, newAntSeq[idx], validateAntSeq[idx]));
			}
		}	
		Antenna.reader.SetReadSequence(antSeq);
	}
	
	public static void AntennaPowerSetting() throws Exception 
	{
		PowerSettings allPSettings = Antenna.reader.GetAntennaPowers();
		
		for (int antNum = 0; antNum < allPSettings.numberOfSettings; antNum++)
			System.out.println(String.format("Power levels for port (%d): read = %6.2f dBm, write = %6.2f dBm", 
											 antNum, allPSettings.readPowers[antNum], allPSettings.writePowers[antNum]));
		
		PowerSettings newPSettings = null;
		
		double[] powerLevels = { 5.0, 12.0, 20.0, 25.0, 30.0, 33.0 };
		
		for (int antNum = 0; antNum < 4; antNum++)
		{
			newPSettings = Antenna.reader.GetAntennaPowers();
			
			for (int wPowNum = 0; wPowNum < powerLevels.length; wPowNum++)
			{
				newPSettings.writePowers[antNum] = powerLevels[wPowNum];
				
				for (int powNum = 0; powNum < powerLevels.length; powNum++)
				{
					newPSettings.readPowers[antNum] = powerLevels[powNum];
					
					if (Antenna.reader.SetAntennaPower(antNum, newPSettings))
					{
						System.out.println(String.format("Set antenna %d powers to (%4.1f, %4.1f) dBm succeeded", antNum, powerLevels[powNum], powerLevels[wPowNum]));
						PowerSettings verifyPSettings = Antenna.reader.GetAntennaPowers();
						
						if (!newPSettings.equals(verifyPSettings))
							System.out.println(String.format("Set antenna %d powers validation failed", antNum, powerLevels[powNum]));						
					}
					else
						System.out.println(String.format("Set antenna %d powers to (%4.1f, %4.1f) dBm failed", antNum, powerLevels[powNum], powerLevels[wPowNum]));
				}
			}
		}
	}
	
	public static void ReadGapTimes() throws Exception
	{
		ReadGapTimes rgt = Antenna.reader.GetReadGapTimes();
		System.out.println(String.format("Read Time: %d ms, Gap Time: %d ms", rgt.readTime, rgt.gapTime));
		
		ReadGapTimes newRgt = new ReadGapTimes(200, 2000);
		
		if (Antenna.reader.SetReadGapTimes(newRgt))
			System.out.println("Set Read/Gap times succeeded");
		else
			System.out.println("Set Read/Gap times failed");				
		
		ReadGapTimes validateRgt = Antenna.reader.GetReadGapTimes();
		
		if (validateRgt.readTime != newRgt.readTime || validateRgt.gapTime != newRgt.gapTime)
			System.out.println("Set Read/Gap times validation check failed");				
		
		Antenna.reader.SetReadGapTimes(rgt);
	}
	
	
	

}
